countries <- c("Zone A","Zone B")
resources <- c("RES","Nuclear","Coal", "Gas")
resources_trade <- c("RES", "RES_import", "Nuclear", "Nuclear_import", 
                    "Coal", "Coal_import", "Gas", "Gas_import")

#### GERMANY 
# de = west zone in germany, amprion
# es = center zone in germany, tennet
germany <- read.delim("data/germany.csv", sep="\t", header=T)
renews_de_big <- data.frame(de_solar = germany$westde_solar, 
					de_wind = germany$westde_wind,
					de_load = germany$westde_load)
renews_de <- renews_de_big[(1:8783)*4,]
renews_es_big <- data.frame(es_solar = germany$centerde_solar, 
					es_wind = germany$centerde_wind,
					es_load = germany$centerde_load)
renews_es <- renews_es_big[(1:8783)*4,]

renews <- cbind(renews_de, renews_es)
renews <- na.omit(renews)

####

freq <- dim(renews)[1]
print(freq)
# res supply
res <- matrix(0, nrow=freq, ncol=2)


colnames(res) <- countries

res[,1] <- renews$de_solar + renews$de_wind
res[,2] <- renews$es_solar + renews$es_wind

res[,1] <- res[,1]/max(res[,1])
res[,2] <- res[,2]/max(res[,2])

## DEMAND: 
baseload <- matrix(0, nrow=freq, ncol=2)
perc_load <- matrix(0, nrow=freq, ncol=2)
baseload[,1] <- renews$de_load + renews$de_solar + renews$de_wind
baseload[,2] <- renews$es_load + renews$es_solar + renews$es_wind
baseload[is.na(baseload)] <- 0

## SUPPLY/FOSSIL and NUCLEAR
gas <- nuc <- coa <- matrix(1, ncol=2, nrow=freq)
colnames(gas) <- colnames(nuc) <- colnames(coa) <- countries

maxload <- apply(baseload, 2, max)
minload <- 0

perc_load[,1] <- baseload[,1]/maxload[1]
perc_load[,2] <- baseload[,2]/maxload[2] 	# with solar, data is complete!

colnames(perc_load) <- countries
summary(perc_load)

# peak load
peak_load <- c(0,0)
names(peak_load) <- countries
peak_load["Zone A"] <- c(peak_A)
peak_load["Zone B"] <- c(peak_B)


# total capacity
tot_cap <- c(0,0)
names(tot_cap) <- countries
tot_cap["Zone A"] <- sum(c(res_A+gas_A+coal_A+nuclear_A))
tot_cap["Zone B"] <- sum(c(res_B+gas_B+coal_B+nuclear_B))

# Demand values: peak*perc_load
demand <- matrix(0, nrow=freq, ncol=2)
colnames(demand) <- countries
for(c in countries){ demand[,c] <- peak_load[c]*perc_load[,c] }

demand[which(demand[,1]==max(demand[,1])),1] <- demand[which(demand[,1]==max(demand[,1])),1]*1.1
demand[which(demand[,2]==max(demand[,2])),2] <- demand[which(demand[,2]==max(demand[,2])),2]*1.1


# variable costs
vc <- matrix(0, nrow=8, ncol=2)
rownames(vc) <- resources_trade
colnames(vc) <- countries

vc[,"Zone A"] <- c(vc_res, vc_res+0.1, vc_nuclear, vc_nuclear+0.1, vc_coal, vc_coal+0.1, vc_gas, vc_gas+0.1)
vc[,"Zone B"] <- c(vc_res, vc_res+0.1, vc_nuclear, vc_nuclear+0.1, vc_coal, vc_coal+0.1, vc_gas, vc_gas+0.1)

# exceeding cost (variable)
exceed <- cost_over

# fixed costs
fc <- matrix(0, nrow=4, ncol=2)
rownames(fc) <- resources
colnames(fc) <- countries

fc[,"Zone A"] <- c(fc_res, fc_nuclear, fc_coal, fc_gas)
fc[,"Zone B"] <- c(fc_res, fc_nuclear, fc_coal, fc_gas)


# Calculate trade limits
trbase <- min(tot_cap)
trlim <- cbind(rep(trbase,freq),rep(trbase,freq))*trade_perc
colnames(trlim) <- countries
